@@ -26,15 +26,6 @@
 
 #include <QProcessEnvironment>
 
-typedef QHash<QString, DiscoverObject::CompactMode> StringCompactMode;
-Q_GLOBAL_STATIC(StringCompactMode,
-                          s_decodeCompactMode,
-                          StringCompactMode{
-                              {QLatin1String("auto"), DiscoverObject::Auto},
-                              {QLatin1String("compact"), DiscoverObject::Compact},
-                              {QLatin1String("full"), DiscoverObject::Full},
-                          })
-
 QCommandLineParser *createParser()
 {
     // clang-format off
@@ -44,7 +35,6 @@ QCommandLineParser *createParser()
     parser->addOption(QCommandLineOption(QStringLiteral("category"), i18n("Display a list of entries with a category."), QStringLiteral("name")));
     parser->addOption(QCommandLineOption(QStringLiteral("mode"), i18n("Open Discover in a said mode. Modes correspond to the toolbar buttons."), QStringLiteral("name")));
     parser->addOption(QCommandLineOption(QStringLiteral("listmodes"), i18n("List all the available modes.")));
-    parser->addOption(QCommandLineOption(QStringLiteral("compact"), i18n("Compact Mode (auto/compact/full)."), QStringLiteral("mode"), QStringLiteral("auto")));
     parser->addOption(QCommandLineOption(QStringLiteral("local-filename"), i18n("Local package file to install"), QStringLiteral("package")));
     parser->addOption(QCommandLineOption(QStringLiteral("listbackends"), i18n("List all the available backends.")));
     parser->addOption(QCommandLineOption(QStringLiteral("search"), i18n("Search string."), QStringLiteral("text")));
@@ -57,36 +47,42 @@ QCommandLineParser *createParser()
     return parser;
 }
 
-void processArgs(QCommandLineParser *parser, DiscoverObject *mainWindow)
+void processArgs(QCommandLineParser *parser, DiscoverObject *discoverObject)
 {
-    if (parser->isSet(QStringLiteral("application")))
-        mainWindow->openApplication(QUrl(parser->value(QStringLiteral("application"))));
-    else if (parser->isSet(QStringLiteral("mime")))
-        mainWindow->openMimeType(parser->value(QStringLiteral("mime")));
-    else if (parser->isSet(QStringLiteral("category")))
-        mainWindow->openCategory(parser->value(QStringLiteral("category")));
-    else if (parser->isSet(QStringLiteral("mode")))
-        mainWindow->openMode(parser->value(QStringLiteral("mode")));
+    if (parser->isSet(QStringLiteral("application"))) {
+        discoverObject->openApplication(QUrl(parser->value(QStringLiteral("application"))));
+    } else if (parser->isSet(QStringLiteral("mime"))) {
+        discoverObject->openMimeType(parser->value(QStringLiteral("mime")));
+    } else if (parser->isSet(QStringLiteral("category"))) {
+        discoverObject->openCategory(parser->value(QStringLiteral("category")));
+    } else if (parser->isSet(QStringLiteral("mode"))) {
+        discoverObject->openMode(parser->value(QStringLiteral("mode")));
+    }
 
-    if (parser->isSet(QStringLiteral("search")))
-        Q_EMIT mainWindow->openSearch(parser->value(QStringLiteral("search")));
+    if (parser->isSet(QStringLiteral("search"))) {
+        Q_EMIT discoverObject->openSearch(parser->value(QStringLiteral("search")));
+    }
 
-    if (parser->isSet(QStringLiteral("local-filename")))
-        mainWindow->openLocalPackage(QUrl::fromUserInput(parser->value(QStringLiteral("local-filename")), {}, QUrl::AssumeLocalFile));
+    if (parser->isSet(QStringLiteral("local-filename"))) {
+        discoverObject->openLocalPackage(QUrl::fromUserInput(parser->value(QStringLiteral("local-filename")), {}, QUrl::AssumeLocalFile));
+    }
 
     const auto positionalArguments = parser->positionalArguments();
     for (const QString &arg : positionalArguments) {
         const QUrl url = QUrl::fromUserInput(arg, {}, QUrl::AssumeLocalFile);
-        if (url.isLocalFile())
-            mainWindow->openLocalPackage(url);
-        else if (url.scheme() == QLatin1String("apt"))
-            Q_EMIT mainWindow->openSearch(url.host());
-        else
-            mainWindow->openApplication(url);
+        if (url.isLocalFile()) {
+            discoverObject->openLocalPackage(url);
+        } else if (url.scheme() == QLatin1String("apt")) {
+            Q_EMIT discoverObject->openSearch(url.host());
+        } else {
+            discoverObject->openApplication(url);
+        }
     }
 
-    if (mainWindow->rootObject()->property("pageStack").value<QObject *>()->property("depth").toInt() == 0) {
-        mainWindow->openMode(QStringLiteral("Browsing"));
+    if (auto window = discoverObject->mainWindow()) {
+        if (window->property("pageStack").value<QObject *>()->property("depth").toInt() == 0) {
+            discoverObject->openMode(QStringLiteral("Browsing"));
+        }
     }
 }
 
@@ -141,7 +137,7 @@ int main(int argc, char **argv)
 
     KAboutData::setApplicationData(about);
 
-    DiscoverObject *mainWindow = nullptr;
+    DiscoverObject *discoverObject = nullptr;
     {
         QScopedPointer<QCommandLineParser> parser(createParser());
         parser->process(app);
@@ -170,47 +166,44 @@ int main(int argc, char **argv)
             options.removeAll(QStringLiteral("test"));
             QVariantMap initialProperties;
             if (!options.isEmpty() || !parser->positionalArguments().isEmpty())
-                initialProperties = {{QStringLiteral("currentTopLevel"), QStringLiteral("qrc:/qml/LoadingPage.qml")}};
+                initialProperties = {{QStringLiteral("currentTopLevel"), QStringLiteral(DISCOVER_BASE_URL "/LoadingPage.qml")}};
             if (feedback) {
                 initialProperties.insert(QStringLiteral("visible"), false);
             }
-            mainWindow = new DiscoverObject(s_decodeCompactMode->value(parser->value(QStringLiteral("compact")), DiscoverObject::Full), initialProperties);
+            discoverObject = new DiscoverObject(initialProperties);
         }
         if (feedback) {
-            QTextStream(stdout) << mainWindow->describeSources() << '\n';
-            delete mainWindow;
+            QTextStream(stdout) << discoverObject->describeSources() << '\n';
+            delete discoverObject;
             return 0;
         } else {
-            auto onActivateRequested = [mainWindow](const QStringList &arguments, const QString & /*workingDirectory*/) {
-                mainWindow->restore();
-                auto window = qobject_cast<QWindow *>(mainWindow->rootObject());
-                if (!window) {
-                    // Should never happen anyway
-                    QCoreApplication::instance()->quit();
-                    return;
-                }
-
-                raiseWindow(window);
-
-                if (arguments.isEmpty())
-                    return;
-                QScopedPointer<QCommandLineParser> parser(createParser());
-                parser->parse(arguments);
-                processArgs(parser.data(), mainWindow);
-            };
-            QObject::connect(service, &KDBusService::activateRequested, mainWindow, onActivateRequested);
+            QObject::connect(service,
+                             &KDBusService::activateRequested,
+                             discoverObject,
+                             [discoverObject](const QStringList &arguments, const QString & /*workingDirectory*/) {
+                                 discoverObject->restore();
+                                 if (auto window = discoverObject->mainWindow()) {
+                                     raiseWindow(window);
+                                     if (arguments.isEmpty()) {
+                                         return;
+                                     }
+                                     QScopedPointer<QCommandLineParser> parser(createParser());
+                                     parser->parse(arguments);
+                                     processArgs(parser.data(), discoverObject);
+                                 }
+                             });
         }
 
-        QObject::connect(&app, &QCoreApplication::aboutToQuit, mainWindow, &DiscoverObject::deleteLater);
+        QObject::connect(&app, &QCoreApplication::aboutToQuit, discoverObject, &DiscoverObject::deleteLater);
 
-        processArgs(parser.data(), mainWindow);
+        processArgs(parser.data(), discoverObject);
 
         if (parser->isSet(QStringLiteral("listmodes"))) {
             QTextStream(stdout) << i18n("Available modes:\n");
-            const auto modes = mainWindow->modes();
+            const auto modes = discoverObject->modes();
             for (const QString &mode : modes)
                 QTextStream(stdout) << " * " << mode << '\n';
-            delete mainWindow;
+            delete discoverObject;
             return 0;
         }
 
@@ -218,7 +211,7 @@ int main(int argc, char **argv)
             const QUrl testFile = QUrl::fromUserInput(parser->value(QStringLiteral("test")), {}, QUrl::AssumeLocalFile);
             Q_ASSERT(!testFile.isEmpty() && testFile.isLocalFile());
 
-            mainWindow->loadTest(testFile);
+            discoverObject->loadTest(testFile);
         }
     }
 
