@@ -55,10 +55,7 @@ public:
     {
         return true;
     }
-    QStringList extends() const override
-    {
-        return m_extends;
-    }
+    bool extends(const QString &extends) const override;
 
     void addSourceFromFlatpakRepo(const QUrl &url, ResultsStream *stream);
     void addAppFromFlatpakBundle(const QUrl &url, ResultsStream *stream);
@@ -103,8 +100,8 @@ private:
     friend class FlatpakSource;
 
     void metadataRefreshed(FlatpakRemote *remote);
+    bool flatpakResourceLessThan(const StreamResult &l, const StreamResult &r) const;
     bool flatpakResourceLessThan(AbstractResource *l, AbstractResource *r) const;
-    void announceRatingsReady();
     FlatpakInstallation *preferredInstallation() const
     {
         return m_installations.constFirst();
@@ -128,7 +125,7 @@ private:
     void updateAppState(FlatpakResource *resource);
     QSharedPointer<FlatpakSource> findSource(FlatpakInstallation *installation, const QString &origin) const;
 
-    QVector<AbstractResource *> resourcesByAppstreamName(const QString &name) const;
+    QVector<StreamResult> resultsByAppstreamName(const QString &name) const;
     void acquireFetching(bool f);
     void checkForRemoteUpdates(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote);
     void createPool(QSharedPointer<FlatpakSource> source);
@@ -139,7 +136,6 @@ private:
     QSharedPointer<OdrsReviewsBackend> m_reviews;
     uint m_isFetching = 0;
     QSet<FlatpakRemote *> m_refreshAppstreamMetadataJobs;
-    QStringList m_extends;
 
     GCancellable *m_cancellable;
     QVector<FlatpakInstallation *> m_installations;
