@@ -5,8 +5,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef FLATPAKRESOURCE_H
-#define FLATPAKRESOURCE_H
+#pragma once
 
 #include <resources/AbstractResource.h>
 
@@ -17,6 +16,7 @@
 
 #include <QAbstractItemModel>
 #include <QPixmap>
+#include <optional>
 
 class AddonList;
 class FlatpakBackend;
@@ -25,13 +25,16 @@ class FlatpakSource;
 class FlatpakResource : public AbstractResource
 {
     Q_OBJECT
-    Q_PROPERTY(QStringList topObjects MEMBER s_objects CONSTANT)
-    Q_PROPERTY(QStringList objects MEMBER s_bottomObjects CONSTANT)
+    Q_PROPERTY(QStringList topObjects MEMBER s_topObjects CONSTANT)
+    Q_PROPERTY(QStringList bottomObjects MEMBER s_bottomObjects CONSTANT)
     Q_PROPERTY(QString attentionText READ attentionText CONSTANT)
     Q_PROPERTY(QString dataLocation READ dataLocation CONSTANT)
     Q_PROPERTY(QString branch READ branch CONSTANT)
     Q_PROPERTY(bool isDesktopApp READ isDesktopApp CONSTANT)
-    Q_PROPERTY(bool hasDataButUninstalled READ hasDataButUninstalled NOTIFY hasDataButUninstalledChanged)
+    Q_PROPERTY(QString eolReason READ eolReason NOTIFY eolReasonChanged)
+    Q_PROPERTY(bool hasData READ hasData NOTIFY hasDataChanged)
+    Q_PROPERTY(QString ref READ ref CONSTANT)
+
 public:
     explicit FlatpakResource(const AppStream::Component &component, FlatpakInstallation *installation, FlatpakBackend *parent);
 
@@ -176,7 +179,7 @@ public:
     void setArch(const QString &arch);
     QString attentionText() const;
     QString dataLocation() const;
-    bool hasDataButUninstalled() const;
+    bool hasData() const;
     Q_INVOKABLE QAbstractListModel *permissionsModel();
 
     void setTemporarySource(const QSharedPointer<FlatpakSource> &temp)
@@ -204,10 +207,12 @@ public:
     {
         return m_type == DesktopApp;
     }
+    QString eolReason();
 
 Q_SIGNALS:
-    void hasDataButUninstalledChanged();
+    void hasDataChanged();
     void propertyStateChanged(FlatpakResource::PropertyKind kind, FlatpakResource::PropertyState state);
+    void eolReasonChanged();
 
 private:
     void setCommit(const QString &commit);
@@ -235,7 +240,8 @@ private:
     FlatpakResource::ResourceType m_type = DesktopApp;
     QSharedPointer<FlatpakSource> m_temp;
     QVector<FlatpakPermission> m_permissions;
-    static const QStringList s_objects;
+    std::optional<QString> m_eolReason;
+    static const QStringList s_topObjects;
     static const QStringList s_bottomObjects;
 };
 
@@ -243,5 +249,3 @@ inline uint qHash(const FlatpakResource::Id &key)
 {
     return qHash(key.id) ^ qHash(key.branch) ^ qHash(key.arch);
 }
-
-#endif // FLATPAKRESOURCE_H
