@@ -6,6 +6,7 @@
  */
 
 #include "FwupdBackend.h"
+#include "../DiscoverVersion.h"
 #include "FwupdResource.h"
 #include "FwupdSourcesBackend.h"
 #include "FwupdTransaction.h"
@@ -34,7 +35,7 @@ FwupdBackend::FwupdBackend(QObject *parent)
         m_isValid = false;
         return;
     }
-    fwupd_client_set_user_agent_for_package(client, "plasma-discover", "1.0");
+    fwupd_client_set_user_agent_for_package(client, "plasma-discover", version.data());
     connect(m_updater, &StandardBackendUpdater::updatesCountChanged, this, &FwupdBackend::updatesCountChanged);
 
     SourcesModel::global()->addSourcesBackend(new FwupdSourcesBackend(this));
@@ -173,7 +174,7 @@ QByteArray FwupdBackend::getChecksum(const QString &filename, QCryptographicHash
 FwupdResource *FwupdBackend::createApp(FwupdDevice *device)
 {
     FwupdRelease *release = fwupd_device_get_release_default(device);
-    QScopedPointer<FwupdResource> app(createRelease(device));
+    std::unique_ptr<FwupdResource> app(createRelease(device));
 
     if (!app->isLiveUpdatable()) {
         qWarning() << "Fwupd Error: " << app->name() << "[" << app->id() << "]"
@@ -197,7 +198,12 @@ FwupdResource *FwupdBackend::createApp(FwupdDevice *device)
         return nullptr;
     }
 
+#if FWUPD_CHECK_VERSION(1, 5, 6)
+    GPtrArray *locations = fwupd_release_get_locations(release);
+    const QUrl update_uri(locations->len == 0 ? QString::fromUtf8("") : QString::fromUtf8((const gchar *)g_ptr_array_index(locations, 0)));
+#else
     const QUrl update_uri(QString::fromUtf8(fwupd_release_get_uri(release)));
+#endif
     if (!update_uri.isValid()) {
         qWarning() << "Fwupd Error: No Update URI available for" << app->name() << "[" << app->id() << "]";
         return nullptr;
@@ -215,7 +221,7 @@ FwupdResource *FwupdBackend::createApp(FwupdDevice *device)
     }
 
     app->setState(AbstractResource::Upgradeable);
-    return app.take();
+    return app.release();
 }
 
 void FwupdBackend::handleError(GError *perror)
@@ -322,13 +328,15 @@ void FwupdBackend::setRemotes(GPtrArray *remotes)
 {
     for (uint i = 0; remotes && i < remotes->len; i++) {
         FwupdRemote *remote = (FwupdRemote *)g_ptr_array_index(remotes, i);
-        if (!fwupd_remote_get_enabled(remote))
+        if (!fwupd_remote_has_flag(remote, FWUPD_REMOTE_FLAG_ENABLED))
             continue;
 
-        if (fwupd_remote_get_kind(remote) == FWUPD_REMOTE_KIND_LOCAL)
+        if (fwupd_remote_get_kind(remote) == FWUPD_REMOTE_KIND_LOCAL
+            || fwupd_remote_get_kind(remote) == FWUPD_REMOTE_KIND_DIRECTORY) {
             continue;
+        }
 
-        fwupd_client_refresh_remote_async(client, remote, m_cancellable, fwupd_client_refresh_remote_cb, this);
+        fwupd_client_refresh_remote2_async(client, remote, FWUPD_CLIENT_DOWNLOAD_FLAG_NONE, m_cancellable, fwupd_client_refresh_remote_cb, this);
     }
 }
 
@@ -362,8 +370,8 @@ ResultsStream *FwupdBackend::search(const AbstractResourcesBackend::Filters &fil
 
     auto stream = new ResultsStream(QStringLiteral("FwupdStream"));
     auto f = [this, stream, filter]() {
-        QVector<AbstractResource *> ret;
-        for (AbstractResource *r : qAsConst(m_resources)) {
+        QVector<StreamResult> ret;
+        for (AbstractResource *r : std::as_const(m_resources)) {
             if (r->state() < filter.state)
                 continue;
 
