@@ -6,10 +6,12 @@
 
 #include "AppPackageKitResource.h"
 #include "utils.h"
+#include <AppStreamQt/developer.h>
 #include <AppStreamQt/icon.h>
 #include <AppStreamQt/image.h>
 #include <AppStreamQt/release.h>
 #include <AppStreamQt/screenshot.h>
+#include <AppStreamQt/version.h>
 #include <KLocalizedString>
 #include <KService>
 #include <PackageKit/Daemon>
@@ -21,6 +23,8 @@
 #include <QUrlQuery>
 #include <appstream/AppStreamUtils.h>
 
+using namespace Qt::StringLiterals;
+
 AppPackageKitResource::AppPackageKitResource(const AppStream::Component &data, const QString &packageName, PackageKitBackend *parent)
     : PackageKitResource(packageName, QString(), parent)
     , m_appdata(data)
@@ -37,7 +41,7 @@ QString AppPackageKitResource::name() const
             if (components.isEmpty())
                 qWarning() << "couldn't find" << m_appdata.extends() << "which is supposedly extended by" << m_appdata.id();
             else
-                m_name = components.constFirst().name() + QLatin1String(" - ") + m_appdata.name();
+                m_name = components.indexSafe(0)->name() + QLatin1String(" - ") + m_appdata.name();
         }
 
         if (m_name.isEmpty())
@@ -138,7 +142,7 @@ QUrl AppPackageKitResource::url() const
     provided.removeAll(appstreamId()); // Just in case, it has happened before
     if (!provided.isEmpty()) {
         QUrlQuery qq;
-        qq.addQueryItem("alt", provided.join(QLatin1Char(',')));
+        qq.addQueryItem(u"alt"_s, provided.join(QLatin1Char(',')));
         ret.setQuery(qq);
     }
     return ret;
@@ -178,8 +182,7 @@ AbstractResource::Type AppPackageKitResource::type() const
 
 void AppPackageKitResource::fetchScreenshots()
 {
-    const auto sc = AppStreamUtils::fetchScreenshots(m_appdata);
-    Q_EMIT screenshotsFetched(sc.first, sc.second);
+    Q_EMIT screenshotsFetched(AppStreamUtils::fetchScreenshots(m_appdata));
 }
 
 QStringList AppPackageKitResource::allPackageNames() const
@@ -193,10 +196,8 @@ QStringList AppPackageKitResource::allPackageNames() const
 
 QList<PackageState> AppPackageKitResource::addonsInformation()
 {
-    const auto res = kFilter<QVector<AppPackageKitResource *>>(backend()->extendedBy(m_appdata.id()), [this](AppPackageKitResource *r) {
-        return r->allPackageNames() != allPackageNames();
-    });
-    return kTransform<QList<PackageState>>(res, [](AppPackageKitResource *r) {
+    auto res = backend()->resourcesByPackageNames<QSet<AbstractResource *>>(m_appdata.extends());
+    return kTransform<QList<PackageState>>(res, [](AbstractResource *r) {
         return PackageState(r->packageName(), r->name(), r->comment(), r->isInstalled());
     });
 }
@@ -237,8 +238,13 @@ QString AppPackageKitResource::versionString()
 
 QDate AppPackageKitResource::releaseDate() const
 {
+#if ASQ_CHECK_VERSION(1, 0, 0)
+    if (!m_appdata.releasesPlain().isEmpty()) {
+        const auto release = m_appdata.releasesPlain().indexSafe(0).value();
+#else
     if (!m_appdata.releases().isEmpty()) {
-        auto release = m_appdata.releases().constFirst();
+        const auto release = m_appdata.releases().constFirst();
+#endif
         return release.timestamp().date();
     }
 
@@ -247,7 +253,7 @@ QDate AppPackageKitResource::releaseDate() const
 
 QString AppPackageKitResource::author() const
 {
-    QString name = m_appdata.developerName();
+    QString name = m_appdata.developer().name();
 
     if (name.isEmpty()) {
         name = m_appdata.projectGroup();
