@@ -33,6 +33,36 @@ struct PackageOrAppId {
 PackageOrAppId makePackageId(const QString &id);
 PackageOrAppId makeAppId(const QString &id);
 
+class Delay : public QObject
+{
+    Q_OBJECT
+public:
+    Delay();
+    void add(const QString &pkgid)
+    {
+        if (!m_delay.isActive()) {
+            m_delay.start();
+        }
+
+        m_pkgids << pkgid;
+    }
+    void add(const QSet<QString> &pkgids)
+    {
+        if (!m_delay.isActive()) {
+            m_delay.start();
+        }
+
+        m_pkgids += pkgids;
+    }
+
+Q_SIGNALS:
+    void perform(const QSet<QString> &pkgids);
+
+private:
+    QTimer m_delay;
+    QSet<QString> m_pkgids;
+};
+
 class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
 {
     Q_OBJECT
@@ -61,12 +91,12 @@ public:
 
     bool isPackageNameUpgradeable(const PackageKitResource *res) const;
     QSet<QString> upgradeablePackageId(const PackageKitResource *res) const;
-    QVector<AppPackageKitResource *> extendedBy(const QString &id) const;
+    QVector<AbstractResource *> extendedBy(const QString &id) const;
 
-    void resolvePackages(const QStringList &packageNames);
+    PKResolveTransaction *resolvePackages(const QStringList &packageNames);
     void fetchDetails(const QString &pkgid)
     {
-        fetchDetails(QSet<QString>{pkgid});
+        m_details.add(pkgid);
     }
     void fetchDetails(const QSet<QString> &pkgid);
 
@@ -79,14 +109,30 @@ public:
     }
     static QString locateService(const QString &filename);
 
-    QList<AppStream::Component> componentsById(const QString &id) const;
+    AppStream::ComponentBox componentsById(const QString &id) const;
     void fetchUpdates();
     int fetchingUpdatesProgress() const override;
+    uint fetchingUpdatesProgressWeight() const override;
 
     InlineMessage *explainDysfunction() const override;
 
     void addPackageArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
     void addPackageNotArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
+    void clear()
+    {
+        m_updatesPackageId.clear();
+    }
+    Delay &updateDetails()
+    {
+        return m_updateDetails;
+    }
+    template<typename T, typename W>
+    T resourcesByPackageNames(const W &names) const;
+
+    QStringList globalHints()
+    {
+        return m_globalHints;
+    }
 
 public Q_SLOTS:
     void reloadPackageList();
@@ -105,23 +151,24 @@ Q_SIGNALS:
 
 private:
     friend class PackageKitResource;
-    template<typename T, typename W>
-    T resourcesByPackageNames(const W &names) const;
 
     template<typename T, typename W>
     T resourcesByAppNames(const W &names) const;
 
     template<typename T>
-    T resourcesByComponents(const QList<AppStream::Component> &names) const;
+    T resourcesByComponents(const AppStream::ComponentBox &names) const;
+
+    QVector<StreamResult> resultsByComponents(const AppStream::ComponentBox &names) const;
 
     void runWhenInitialized(const std::function<void()> &f, QObject *stream);
 
     void checkDaemonRunning();
     void acquireFetching(bool f);
     void includePackagesToAdd();
-    void performDetailsFetch();
-    AppPackageKitResource *addComponent(const AppStream::Component &component);
+    void performDetailsFetch(const QSet<QString> &pkgids);
+    AppPackageKitResource *addComponent(const AppStream::Component &component) const;
     void updateProxy();
+    void foundNewMajorVersion(const AppStream::Release &release);
 
     QScopedPointer<AppStream::Pool> m_appdata;
     PackageKitUpdater *m_updater;
@@ -129,20 +176,19 @@ private:
     int m_isFetching;
     QSet<QString> m_updatesPackageId;
     bool m_hasSecurityUpdates = false;
-    QSet<PackageKitResource *> m_packagesToAdd;
+    mutable QHash<PackageOrAppId, PackageKitResource *> m_packagesToAdd;
     QSet<PackageKitResource *> m_packagesToDelete;
     bool m_appstreamInitialized = false;
 
-    struct {
+    mutable struct {
         QHash<PackageOrAppId, AbstractResource *> packages;
         QHash<QString, QStringList> packageToApp;
-        QHash<QString, QVector<AppPackageKitResource *>> extendedBy;
     } m_packages;
 
-    QTimer m_delayedDetailsFetch;
-    QSet<QString> m_packageNamesToFetchDetails;
+    Delay m_details;
+    Delay m_updateDetails;
     QSharedPointer<OdrsReviewsBackend> m_reviews;
-    QPointer<PackageKit::Transaction> m_getUpdatesTransaction;
     QThreadPool m_threadPool;
     QPointer<PKResolveTransaction> m_resolveTransaction;
+    QStringList m_globalHints;
 };
