@@ -3,9 +3,9 @@
  *
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
-#ifndef PACKAGEKITNOTIFIER_H
-#define PACKAGEKITNOTIFIER_H
+#pragma once
 
+#include <AppStreamQt/pool.h>
 #include <BackendNotifierModule.h>
 #include <PackageKit/Transaction>
 #include <QPointer>
@@ -32,13 +32,13 @@ public:
     {
         return m_needsReboot;
     }
+    void checkDistroUpgrade();
 
 private Q_SLOTS:
     void package(PackageKit::Transaction::Info info, const QString &packageID, const QString &summary);
     void finished(PackageKit::Transaction::Exit exit, uint);
     void onRequireRestart(PackageKit::Transaction::Restart type, const QString &packageID);
     void transactionListChanged(const QStringList &tids);
-    void onDistroUpgrade(PackageKit::Transaction::DistroUpgrade type, const QString &name, const QString &description);
 
 private:
     void nowNeedsReboot();
@@ -50,11 +50,10 @@ private:
     bool m_needsReboot = false;
     uint m_securityUpdates;
     uint m_normalUpdates;
+    bool m_hasDistUpgrade;
     QPointer<PackageKit::Transaction> m_refresher;
-    QPointer<PackageKit::Transaction> m_distUpgrades;
     QTimer *m_recheckTimer;
 
     QHash<QString, PackageKit::Transaction *> m_transactions;
+    std::unique_ptr<AppStream::Pool> m_appdata;
 };
-
-#endif
