@@ -3,8 +3,7 @@
  *
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
-#ifndef PACKAGEKITUPDATER_H
-#define PACKAGEKITUPDATER_H
+#pragma once
 
 #include "PackageKitBackend.h"
 #include <PackageKit/Transaction>
@@ -47,6 +46,9 @@ public:
 
     void proceed() override;
     void setOfflineUpdates(bool use) override;
+    void setDistroUpgrade(const AppStream::Release &release);
+    void clearDistroUpgrade();
+    bool isDistroUpgrade() const;
 
 public Q_SLOTS:
     /// must be implemented if ever isCancelable is true
@@ -107,5 +109,3 @@ private:
 
     SystemUpgrade *m_upgrade = nullptr;
 };
-
-#endif
