@@ -4,14 +4,15 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef ABSTRACTRESOURCESBACKEND_H
-#define ABSTRACTRESOURCESBACKEND_H
+#pragma once
 
 #include <QObject>
 #include <QPair>
+#include <QVariantList>
 #include <QVector>
 
 #include "AbstractResource.h"
+#include "DiscoverAction.h"
 #include "Transaction/AddonList.h"
 
 #include "discovercommon_export.h"
@@ -21,6 +22,27 @@ class Category;
 class AbstractReviewsBackend;
 class AbstractBackendUpdater;
 
+struct StreamResult {
+    StreamResult(AbstractResource *resource = nullptr, uint sortScore = 0)
+        : resource(resource)
+        , sortScore(sortScore)
+    {
+    }
+
+    AbstractResource *resource = nullptr;
+    uint sortScore = 0;
+
+    bool operator==(const StreamResult &other) const
+    {
+        return resource == other.resource;
+    }
+};
+
+inline size_t qHash(const StreamResult &key, size_t seed = 0)
+{
+    return qHash(quintptr(key.resource), seed);
+}
+
 class DISCOVERCOMMON_EXPORT ResultsStream : public QObject
 {
     Q_OBJECT
@@ -28,42 +50,53 @@ public:
     ResultsStream(const QString &objectName);
 
     /// assumes all the information is in @p resources
-    ResultsStream(const QString &objectName, const QVector<AbstractResource *> &resources);
+    ResultsStream(const QString &objectName, const QVector<StreamResult> &resources);
     ~ResultsStream() override;
 
     void finish();
 
 Q_SIGNALS:
-    void resourcesFound(const QVector<AbstractResource *> &resources);
+    void resourcesFound(const QVector<StreamResult> &resources);
     void fetchMore();
 };
 
-class DISCOVERCOMMON_EXPORT HelpfulError : public QObject
+class DISCOVERCOMMON_EXPORT InlineMessage : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(QString iconName MEMBER m_iconName CONSTANT)
-    Q_PROPERTY(QString errorMessage MEMBER m_errorMessage CONSTANT)
-    Q_PROPERTY(QVariantList actions MEMBER m_actions CONSTANT)
 public:
-    HelpfulError(const QString &iconName, const QString &error, const QVariantList &actions = {})
-        : m_iconName(iconName)
-        , m_errorMessage(error)
-        , m_actions(actions)
+    // Keep in sync with Kirigami's in enums.h
+    enum InlineMessageType {
+        Information = 0,
+        Positive,
+        Warning,
+        Error,
+    };
+    Q_ENUM(InlineMessageType)
+    Q_PROPERTY(InlineMessageType type MEMBER type CONSTANT)
+    Q_PROPERTY(QString iconName MEMBER iconName CONSTANT)
+    Q_PROPERTY(QString message MEMBER message CONSTANT)
+    Q_PROPERTY(QVariantList actions MEMBER actions CONSTANT)
+
+    InlineMessage(InlineMessageType type, const QString &iconName, const QString &message, DiscoverAction *action = nullptr)
+        : type(type)
+        , iconName(iconName)
+        , message(message)
+        , actions(action ? QVariantList{QVariant::fromValue<QObject *>(action)} : QVariantList())
     {
     }
 
-private:
-    QString m_iconName;
-    QString m_errorMessage;
-    QVariantList m_actions;
-};
+    InlineMessage(InlineMessageType type, const QString &iconName, const QString &message, const QVariantList &actions)
+        : type(type)
+        , iconName(iconName)
+        , message(message)
+        , actions(actions)
+    {
+    }
 
-// Keep in sync with Kirigami's enums.h
-enum InlineMessageType {
-    Information = 0,
-    Positive,
-    Warning,
-    Error,
+    InlineMessageType type;
+    const QString iconName;
+    const QString message;
+    const QVariantList actions;
 };
 
 /**
@@ -78,7 +111,7 @@ enum InlineMessageType {
  * As this is the base class of a backend, we save all the created resources here and also
  * accept calls to install and remove applications or to cancel transactions.
  *
- * To show resources in Muon, we need to initialize all resources we want to show beforehand,
+ * To show resources in Discover, we need to initialize all resources we want to show beforehand,
  * we should not create resources in the search function. When we reload the resources
  * (e.g. when initializing), the backend needs change the fetching property throughout the
  * process.
@@ -127,6 +160,7 @@ public:
 
         bool shouldFilter(AbstractResource *res) const;
         void filterJustInCase(QVector<AbstractResource *> &input) const;
+        void filterJustInCase(QVector<StreamResult> &input) const;
     };
 
     /**
@@ -141,7 +175,7 @@ public:
     virtual AbstractReviewsBackend *reviewsBackend() const = 0; // FIXME: Have a standard impl which returns 0?
 
     /**
-     * @returns the class which is used by muon to update the users system, if you are unsure what to do
+     * @returns the class which is used by Discover to update the users system, if you are unsure what to do
      * just return the StandardBackendUpdater
      */
     virtual AbstractBackendUpdater *backendUpdater() const = 0; // FIXME: Standard impl returning the standard updater?
@@ -167,7 +201,7 @@ public:
     /**
      * @returns the appstream ids that this backend extends
      */
-    virtual QStringList extends() const;
+    virtual bool extends(const QString &id) const;
 
     /** @returns the plugin's name */
     QString name() const;
@@ -197,6 +231,12 @@ public:
 
     virtual int fetchingUpdatesProgress() const;
 
+    /**
+     * @returns how much this backend should influence the global fetching progress.
+     * This is not a percentage.
+     */
+    virtual uint fetchingUpdatesProgressWeight() const;
+
 public Q_SLOTS:
     /**
      * This gets called when the backend should install an application.
@@ -232,7 +272,7 @@ public Q_SLOTS:
     /**
      * Provides a guess why a search might not have offered satisfactory results
      */
-    Q_SCRIPTABLE virtual HelpfulError *explainDysfunction() const;
+    Q_SCRIPTABLE virtual InlineMessage *explainDysfunction() const;
 
 Q_SIGNALS:
     /**
@@ -257,7 +297,7 @@ Q_SIGNALS:
     void resourceRemoved(AbstractResource *resource);
 
     void passiveMessage(const QString &message);
-    void inlineMessage(InlineMessageType type, const QString &iconName, const QString &message);
+    void inlineMessageChanged(const QSharedPointer<InlineMessage> &inlineMessage);
     void fetchingUpdatesProgressChanged();
 
 private:
@@ -292,5 +332,3 @@ public:
     };
 
 Q_DECLARE_INTERFACE(AbstractResourcesBackendFactory, "org.kde.muon.AbstractResourcesBackendFactory")
-
-#endif // ABSTRACTRESOURCESBACKEND_H
