@@ -7,7 +7,7 @@
 #include <Category/CategoriesReader.h>
 #include <Category/Category.h>
 #include <QList>
-#include <QtTest>
+#include <QTest>
 
 class CategoriesTest : public QObject
 {
@@ -47,6 +47,15 @@ private Q_SLOTS:
     {
         auto categories = populateCategories();
         QVERIFY(!categories.isEmpty());
+
+        for (Category *c : categories) {
+            if (c->name() != QLatin1String("Dummy Category"))
+                continue;
+
+            auto filter = c->filter();
+            QVERIFY(filter.type == CategoryFilter::CategoryNameFilter);
+            QVERIFY(std::get<QString>(filter.value) == QLatin1String("dummy"));
+        }
     }
 };
 
