@@ -11,14 +11,11 @@
 #include <KNotificationJobUiDelegate>
 #include <KPluginFactory>
 #include <QDBusConnection>
+#include <QDBusConnectionInterface>
 #include <QDBusMessage>
 #include <QDBusPendingCall>
 #include <QDebug>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QNetworkConfigurationManager>
-#else
 #include <QNetworkInformation>
-#endif
 #include <QProcess>
 
 #include <KIO/ApplicationLauncherJob>
@@ -35,21 +32,19 @@ DiscoverNotifier::DiscoverNotifier(QObject *parent)
 {
     m_settings = new UpdatesSettings(this);
     m_settingsWatcher = KConfigWatcher::create(m_settings->sharedConfig());
-#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
-    QNetworkInformation::instance()->load(QNetworkInformation::Feature::Reachability | QNetworkInformation::Feature::TransportMedium);
+    QNetworkInformation::instance()->loadBackendByFeatures(QNetworkInformation::Feature::Reachability | QNetworkInformation::Feature::TransportMedium);
     connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, &DiscoverNotifier::stateChanged);
     connect(QNetworkInformation::instance(), &QNetworkInformation::transportMediumChanged, this, &DiscoverNotifier::stateChanged);
-#endif
 
     refreshUnattended();
     connect(m_settingsWatcher.data(), &KConfigWatcher::configChanged, this, [this](const KConfigGroup &group, const QByteArrayList &names) {
-        if (group.config()->name() == m_settings->config()->name() && group.name() == "Global" && names.contains("UseUnattendedUpdates")) {
+        if (group.config()->name() == m_settings->config()->name() && group.name() == QLatin1String("Global") && names.contains("UseUnattendedUpdates")) {
             refreshUnattended();
         }
     });
 
     m_backends = BackendNotifierFactory().allBackends();
-    for (BackendNotifierModule *module : qAsConst(m_backends)) {
+    for (BackendNotifierModule *module : std::as_const(m_backends)) {
         connect(module, &BackendNotifierModule::foundUpdates, this, &DiscoverNotifier::updateStatusNotifier);
         connect(module, &BackendNotifierModule::needsRebootChanged, this, [this]() {
             // If we are using offline updates, there is no need to badger the user to
@@ -120,6 +115,10 @@ bool DiscoverNotifier::notifyAboutUpdates() const
 
     m_settings->setLastNotificationTime(QDateTime::currentDateTimeUtc());
     m_settings->save();
+
+    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.discover"))) {
+        return false;
+    }
     return true;
 }
 
@@ -133,20 +132,20 @@ void DiscoverNotifier::showUpdatesNotification()
         return;
     }
 
-    m_updatesAvailableNotification = KNotification::event(QStringLiteral("Update"),
-                                                          message(),
-                                                          {},
-                                                          iconName(),
-                                                          nullptr,
-                                                          KNotification::CloseOnTimeout,
-                                                          QStringLiteral("discoverabstractnotifier"));
+    m_updatesAvailableNotification =
+        KNotification::event(QStringLiteral("Update"), message(), {}, iconName(), KNotification::CloseOnTimeout, QStringLiteral("discoverabstractnotifier"));
     m_updatesAvailableNotification->setHint(QStringLiteral("resident"), true);
     const QString name = i18n("View Updates");
-    m_updatesAvailableNotification->setDefaultAction(name);
-    m_updatesAvailableNotification->setActions({name});
-    connect(m_updatesAvailableNotification, QOverload<unsigned int>::of(&KNotification::activated), this, [this] {
+
+    auto showUpdates = [this] {
         showDiscoverUpdates(m_updatesAvailableNotification->xdgActivationToken());
-    });
+    };
+
+    auto defaultAction = m_updatesAvailableNotification->addDefaultAction(name);
+    connect(defaultAction, &KNotificationAction::activated, this, showUpdates);
+
+    auto showUpdatesAction = m_updatesAvailableNotification->addAction(name);
+    connect(showUpdatesAction, &KNotificationAction::activated, this, showUpdates);
 }
 
 void DiscoverNotifier::updateStatusNotifier()
@@ -172,12 +171,6 @@ void DiscoverNotifier::updateStatusNotifier()
 }
 
 // we only want to do unattended updates when on an ethernet or wlan network
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-static bool isConnectionAdequate(const QNetworkConfiguration &network)
-{
-    return (network.bearerType() == QNetworkConfiguration::BearerEthernet || network.bearerType() == QNetworkConfiguration::BearerWLAN);
-}
-#elif QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
 static bool isConnectionAdequate()
 {
     const auto info = QNetworkInformation::instance();
@@ -188,7 +181,6 @@ static bool isConnectionAdequate()
         return transport == QNetworkInformation::TransportMedium::Ethernet || transport == QNetworkInformation::TransportMedium::WiFi;
     }
 }
-#endif
 
 void DiscoverNotifier::refreshUnattended()
 {
@@ -198,12 +190,8 @@ void DiscoverNotifier::refreshUnattended()
         return;
     }
 
-    const auto enabled = m_settings->useUnattendedUpdates()
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        && m_manager->isOnline() && isConnectionAdequate(m_manager->defaultConfiguration());
-#elif QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
-        && QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online && isConnectionAdequate();
-#endif
+    const auto enabled = m_settings->useUnattendedUpdates() && QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online
+        && isConnectionAdequate();
     if (bool(m_unattended) == enabled)
         return;
 
@@ -221,11 +209,7 @@ DiscoverNotifier::State DiscoverNotifier::state() const
         return RebootRequired;
     else if (m_isBusy)
         return Busy;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    else if (m_manager && !m_manager->isOnline())
-#else
     else if (QNetworkInformation::instance()->reachability() != QNetworkInformation::Reachability::Online)
-#endif
         return Offline;
     else if (m_hasSecurityUpdates)
         return SecurityUpdates;
@@ -275,17 +259,7 @@ QString DiscoverNotifier::message() const
 
 void DiscoverNotifier::recheckSystemUpdateNeeded()
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (!m_manager) {
-        m_manager = new QNetworkConfigurationManager(this);
-        connect(m_manager, &QNetworkConfigurationManager::onlineStateChanged, this, &DiscoverNotifier::stateChanged);
-        if (!m_manager->isOnline()) {
-            Q_EMIT stateChanged();
-        }
-    }
-#endif
-
-    for (BackendNotifierModule *module : qAsConst(m_backends))
+    for (BackendNotifierModule *module : std::as_const(m_backends))
         module->recheckSystemUpdateNeeded();
 
     refreshUnattended();
@@ -305,13 +279,11 @@ void DiscoverNotifier::showRebootNotification()
                                                        i18n("Restart is required"),
                                                        i18n("The system needs to be restarted for the updates to take effect."),
                                                        QStringLiteral("system-software-update"),
-                                                       nullptr,
                                                        KNotification::Persistent | KNotification::DefaultEvent,
                                                        QStringLiteral("discoverabstractnotifier"));
 
-    notification->setActions(QStringList{i18nc("@action:button", "Restart")});
-    notification->setDefaultAction(notification->actions().constFirst());
-    connect(notification, &KNotification::action1Activated, this, &DiscoverNotifier::reboot);
+    auto restartAction = notification->addAction(i18nc("@action:button", "Restart"));
+    connect(restartAction, &KNotificationAction::activated, this, &DiscoverNotifier::reboot);
 
     notification->sendEvent();
 }
@@ -327,16 +299,27 @@ void DiscoverNotifier::reboot()
 
 void DiscoverNotifier::foundUpgradeAction(UpgradeAction *action)
 {
-    KNotification *notification = new KNotification(QStringLiteral("distupgrade-notification"), KNotification::Persistent | KNotification::DefaultEvent);
-    notification->setIconName(QStringLiteral("system-software-update"));
-    notification->setActions(QStringList{i18nc("@action:button", "Upgrade")});
-    notification->setTitle(i18n("Upgrade available"));
-    notification->setText(i18n("New version: %1", action->description()));
+    updateStatusNotifier();
 
-    connect(notification, &KNotification::action1Activated, this, [action]() {
+    if (!notifyAboutUpdates()) {
+        return;
+    }
+
+    KNotification *notification = new KNotification(QStringLiteral("DistUpgrade"), KNotification::Persistent);
+    notification->setIconName(QStringLiteral("system-software-update"));
+    notification->setTitle(i18n("Upgrade available"));
+    notification->setText(i18nc("A new distro release (name and version) is available for upgrade", "%1 is now available.", action->description()));
+    notification->setComponentName(QStringLiteral("discoverabstractnotifier"));
+
+    auto upgradeAction = notification->addAction(i18nc("@action:button", "Upgrade"));
+    connect(upgradeAction, &KNotificationAction::activated, this, [action] {
         action->trigger();
     });
 
+    connect(action, &UpgradeAction::showDiscoverUpdates, this, [this, notification]() {
+        showDiscoverUpdates(notification->xdgActivationToken());
+    });
+
     notification->sendEvent();
 }
 
