@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef DISCOVERNOTIFIERMODULE_H
-#define DISCOVERNOTIFIERMODULE_H
+#pragma once
 
 #include <BackendNotifierModule.h>
 #include <QPointer>
@@ -16,9 +15,6 @@
 #include <KNotification>
 
 class KNotification;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-class QNetworkConfigurationManager;
-#endif
 class UnattendedUpdates;
 class UpdatesSettings;
 
@@ -100,13 +96,8 @@ private:
     bool m_hasUpdates = false;
     bool m_needsReboot = false;
     bool m_isBusy = false;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QNetworkConfigurationManager *m_manager = nullptr;
-#endif
     QPointer<KNotification> m_updatesAvailableNotification;
     UnattendedUpdates *m_unattended = nullptr;
     KConfigWatcher::Ptr m_settingsWatcher;
     UpdatesSettings *m_settings;
 };
-
-#endif // ABSTRACTKDEDMODULE_H
